@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 use File::HomeDir;
-
-use Path::Tiny; # For path().
+use File::Spec;
 
 # --------------
 
@@ -13,7 +12,7 @@ my($module)      = 'GraphViz2';
 my($module_dir)  = $module;
 $module_dir      =~ s/::/-/g;
 my($config_name) = '.htgraphviz2.conf';
-my($path)        = path(File::HomeDir -> my_dist_config($module_dir), $config_name);
+my($path)        = File::Spec -> catfile(File::HomeDir -> my_dist_config($module_dir), $config_name);
 
 print "Using: File::HomeDir -> my_dist_config('$module_dir', '$config_name'): \n";
 print "Found: $path\n";
