@@ -37,7 +37,7 @@ my($graph) = GraphViz2 -> new
 
 $graph -> add_node(name => 'Carnegie',  shape => 'circle');
 $graph -> add_node(name => 'Chadstone', shape => 'circle', color => 'red');
-$graph -> add_node(name => 'Malvern',   shape => 'box', color => 'green');
+$graph -> add_node(name => 'Malvern',   shape => 'doublecircle', color => 'green');
 $graph -> add_node(name => 'Murrumbeena', shape => 'square', color => 'orange');
 $graph -> add_node(name => 'Oakleigh',  color => 'blue');
 
